@@ -4,17 +4,10 @@ from django.utils import simplejson
 import locale
 from smart_selects.utils import unicode_sorter
 
-def filterchain(request, app, model, field, value, manager=None):
+def filterchain(request, app, model, field, value):
     Model = get_model(app, model)
-    if value == '0':
-        keywords = {str("%s__isnull" % field):True}
-    else:
-        keywords = {str(field): str(value)}
-    if manager is not None and hasattr(Model, manager):
-        queryset = getattr(Model, manager).all()
-    else:
-        queryset = Model.objects
-    results = list(queryset.filter(**keywords))
+    keywords = {str(field): str(value)}
+    results = list(Model.objects.filter(**keywords))
     results.sort(cmp=locale.strcoll, key=lambda x:unicode_sorter(unicode(x)))
     result = []
     for item in results:
@@ -24,10 +17,7 @@ def filterchain(request, app, model, field, value, manager=None):
 
 def filterchain_all(request, app, model, field, value):
     Model = get_model(app, model)
-    if value == '0':
-        keywords = {str("%s__isnull" % field):True}
-    else:
-        keywords = {str(field): str(value)}
+    keywords = {str(field): str(value)}
     results = list(Model.objects.filter(**keywords))
     results.sort(cmp=locale.strcoll, key=lambda x:unicode_sorter(unicode(x)))
     final = []
@@ -36,7 +26,7 @@ def filterchain_all(request, app, model, field, value):
     results = list(Model.objects.exclude(**keywords))
     results.sort(cmp=locale.strcoll, key=lambda x:unicode_sorter(unicode(x)))
     final.append({'value':"", 'display':"---------"})
-
+    
     for item in results:
         final.append({'value':item.pk, 'display':unicode(item)})
     json = simplejson.dumps(final)
